==> xbill-1.0.tgz: xbill/text.h <==
/* Try to keep lines around 48 chars or so... */

char *story_txt = 
"Yet again, the fate of the world rests in your\n\
hands!  An evil computer hacker, known only by\n\
his handle 'Bill', has created the ultimate\n\
computer virus.  A virus so powerful that it\n\
has the power to transmute an ordinary computer\n\
into a toaster oven.  (oooh!) 'Bill' has cloned\n\
himself into a billion-jillion micro-Bills.\n\
Their sole purpose is to deliver the nefarious\n\
virus, which has been cleverly diguised as a\n\
popular operating system.\n\
\n\
As System Administrator/Exterminator, your job\n\
is to keep Bill from succeeding at his task.";


char *thanks_txt = 
"Greg Seidman    - for the imakefile\n\
                  & stimulating obnoxious comments\n\
\n\
Josh Adams      - for the Macintosh Port\n\
                  & his girlfriend for our amusement\n\
\n\
Chris Vance     - for being there & playtesting\n\
\n\
Erik Hanson     - for a big fat nothing!\n\
\n\
Patrick Murray  - for moral support & playtesting\n\
\n\
Jennifer Carter - for loving Matias";


char *rules_txt = 
"xBill has been painstakingly designed and\n\
researched in order to make it as easy to\n\
use for the whole family as it is for little\n\
Sally.  Years - nay - days of beta testing\n\
and consulting with the cheapest of human\n\
interface designers have resulted in a game\n\
that is easy to use and works nothing at all\n\
like a Macintosh.\n\
\n\
I.   Whack the Bills (click)\n\
II.  Restart the computer (click)\n\
III. Pick up stolen OSes and return them to
     their respective computers (drag)\n\
IV.  Scoring is based on total uptime, with
     bonuses for killing Bills.\n\
\n\
As for the rest, you can probably figure it\n\
out.  We did, so it can't be too hard.";

char *freeware_txt =
"It's FREE! If you want to express your undying\n\
gratitude to us for bringing a small bit of\n\
meaning into your otherwise pointless existence,\n\
you could always send us e-mail. Or even better\n\
would be a cool job for Brian.  Matias already\n\
has one. He wouldn't mind that at all.  Really.\n\
\n\
Go play the game now!";

char *endgame_txt = 
"Module xBill has caused a segmentation fault\n\
at memory address 097E:F1A0.  Core dumped.\n\
\n\
    We apologize for the inconvenience.";

==> xbill-1.1.tgz: xbill/text.h <==
#ifndef TEXT_H
#define TEXT_H

/* Try to keep lines around 48 chars or so... */

char *story_txt = 
"Yet again, the fate of the world rests in your\n\
hands!  An evil computer hacker, known only by\n\
his handle 'Bill', has created the ultimate\n\
computer virus.  A virus so powerful that it\n\
has the power to transmute an ordinary computer\n\
into a toaster oven.  (oooh!) 'Bill' has cloned\n\
himself into a billion-jillion micro-Bills.\n\
Their sole purpose is to deliver the nefarious\n\
virus, which has been cleverly diguised as a\n\
popular operating system.\n\
\n\
As System Administrator/Exterminator, your job\n\
is to keep Bill from succeeding at his task.";


char *thanks_txt = 
"Greg Seidman    - for lots of help & suggestions\n\
\n\
Josh Adams      - for the Macintosh Port\n\
\n\
Eric Gandt      \n\
Chris Vance     \n\
Erik Hanson     \n\
Patrick Murray  - playtesting & suggestions\n\
\n\
David Nedde     - the Athena DrawingArea widget\n\
\n\
Jennifer Carter - for loving Matias";


char *rules_txt = 
"xBill has been painstakingly designed and\n\
researched in order to make it as easy to\n\
use for the whole family as it is for little\n\
Sally.  Years - nay - days of beta testing\n\
and consulting with the cheapest of human\n\
interface designers have resulted in a game\n\
that is easy to use and works nothing at all\n\
like a Macintosh.\n\
\n\
I.   Whack the Bills (click)\n\
II.  Restart the computer (click)\n\
III. Pick up stolen OSes and return them to
     their respective computers (drag)\n\
IV.  Scoring is based on total uptime, with
     bonuses for killing Bills.\n\
\n\
As for the rest, you can probably figure it\n\
out.  We did, so it can't be too hard.";

char *freeware_txt =
"It's FREE! If you want to express your undying\n\
gratitude to us for bringing a small bit of\n\
meaning into your otherwise pointless existence,\n\
you could always send us e-mail. Or even better\n\
would be a cool job for Brian.  He wouldn't mind\n\
that at all.  Really.  Matias already has one.\n\
\n\
Go play the game now!";

char *endgame_txt = 
"Module xBill has caused a segmentation fault\n\
at memory address 097E:F1A0.  Core dumped.\n\
\n\
    We apologize for the inconvenience.";

#endif
